@@ -264,6 +264,7 @@ def getHyperparameters(configFile, videoName, videoPath, argv):
   
   hyperparameters["adjustHeadEmbededTracking"] = getConfig(config, "adjustHeadEmbededTracking", videoPath)
   hyperparameters["adjustFreelySwimTracking"] = getConfig(config, "adjustFreelySwimTracking", videoPath)
+  hyperparameters["adjustFreelySwimTrackingAutomaticParameters"] = getConfig(config, "adjustFreelySwimTrackingAutomaticParameters", videoPath)
   
   hyperparameters["overwriteFirstStepValue"] = getConfig(config, "overwriteFirstStepValue", videoPath)
   hyperparameters["overwriteLastStepValue"]  = getConfig(config, "overwriteLastStepValue", videoPath)
@@ -408,7 +409,15 @@ def getHyperparameters(configFile, videoName, videoPath, argv):
   hyperparameters["simpleThresholdCheckMinForMaxCountour"] = getConfig(config, "simpleThresholdCheckMinForMaxCountour", videoPath)
   
   hyperparameters["rectangularWellMinMaxXandYmethod"] = getConfig(config, "rectangularWellMinMaxXandYmethod", videoPath)
+  hyperparameters["rectangularWellMinMaxXandYmethodMargin"] = getConfig(config, "rectangularWellMinMaxXandYmethodMargin", videoPath)
   
+  hyperparameters["addOneFrameAtTheEndForBoutDetection"] = getConfig(config, "addOneFrameAtTheEndForBoutDetection", videoPath)
+  
+  hyperparameters["boutsMinNbFrames"] = getConfig(config, "boutsMinNbFrames", videoPath)
+  
+  hyperparameters["trackOnlyOnROI_halfDiameter"] = getConfig(config, "trackOnlyOnROI_halfDiameter", videoPath)
+  
+  hyperparameters["detectMovementWithRawVideoInsideTracking"] = getConfig(config, "detectMovementWithRawVideoInsideTracking", videoPath)
   
   if hyperparameters["tailAnglesHeatMap"]:
     hyperparameters["calculateAllTailAngles"] = 1
