@@ -1,3 +1,4 @@
+from zebrazoom.code.preprocessImage import preprocessImage
 import numpy as np
 import cv2
 
@@ -13,6 +14,12 @@ def headEmbededFrameSequentialBackExtract(cap, videoPath, background, hyperparam
     frameNumber = frameNumber - 1
     cap.set(1, frameNumber)
     ret, frame = cap.read()
+    
+  if hyperparameters["invertBlackWhiteOnImages"]:
+    frame = 255 - frame
+    
+  if hyperparameters["imagePreProcessMethod"]:
+    frame = preprocessImage(frame, hyperparameters)
   
   kernel = np.ones((8,8),np.float32)/25
   thres1  = cv2.filter2D(frame,-1,kernel)
@@ -26,7 +33,7 @@ def headEmbededFrameSequentialBackExtract(cap, videoPath, background, hyperparam
     cv2.waitKey(0)
   
   putToWhite = ( frame.astype('int32') >= (background.astype('int32') + minPixelDiffForBackExtract) )
-
+  # This puts the pixels that belong to a fish to white
   frame[putToWhite] = 255
   
   if (debug):
